@@ -1,14 +1,24 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
+# Copyright 2013 David Farr <david.farr@sap.com>                               #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2015 Ed Holland <eholland@alertlogic.com>                          #
+# Copyright 2016 John Eskew <jeskew@edx.org>                                   #
+# Copyright 2016 Matthew Neal <meneal@matthews-mbp.raleigh.ibm.com>            #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2016 Sam Corbett <sam.corbett@cloudsoftcorp.com>                   #
+# Copyright 2017 Aaron Levine <allevin@sandia.gov>                             #
+# Copyright 2017 Nicolas Agustín Torres <nicolastrres@gmail.com>              #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -23,7 +33,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
 
 from .AuthenticatedUser import *
 from .Authentication import *
@@ -50,6 +60,7 @@ from .Issue import *
 from .IssueComment import *
 from .Reaction import *
 from .IssueEvent import *
+from .License import *
 from .Label import *
 from .Milestone import *
 from .NamedUser import *
@@ -64,6 +75,7 @@ from .PullRequestFile import *
 from .RateLimiting import *
 from .Repository import *
 from .RepositoryKey import *
+from .SourceImport import *
 from .Status import *
 from .Tag import *
 from .Team import *
@@ -98,3 +110,4 @@ from .Issue214 import *
 from .Issue216 import *
 from .Issue278 import *
 from .Issue494 import *
+from .Issue572 import *
