@@ -39,14 +39,16 @@ class Label(Framework.TestCase):
     def testAttributes(self):
         self.assertEqual(self.label.color, "e10c02")
         self.assertEqual(self.label.name, "Bug")
+        self.assertIsNone(self.label.description)
         self.assertEqual(self.label.url, "https://api.github.com/repos/jacquev6/PyGithub/labels/Bug")
 
         # test __repr__() based on this attributes
         self.assertEqual(self.label.__repr__(), 'Label(name="Bug")')
 
     def testEdit(self):
-        self.label.edit("LabelEditedByPyGithub", "0000ff")
+        self.label.edit("LabelEditedByPyGithub", "0000ff", "Description of LabelEditedByPyGithub")
         self.assertEqual(self.label.color, "0000ff")
+        self.assertEqual(self.label.description, "Description of LabelEditedByPyGithub")
         self.assertEqual(self.label.name, "LabelEditedByPyGithub")
         self.assertEqual(self.label.url, "https://api.github.com/repos/jacquev6/PyGithub/labels/LabelEditedByPyGithub")
 
